@@ -4,8 +4,8 @@
 
 ;; Author: Andreas Stuhlmueller <andreas@ought.org>
 ;; Maintainer: Anselm Coogan <anselm.coogan@gmail.com>
-;; Package-Version: 20251203.1304
-;; Package-Revision: a05675c3855f
+;; Package-Version: 20260202.1935
+;; Package-Revision: dd5e0cdec646
 ;; Keywords: openai, anthropic, deepseek, gpt, claude, language, copilot, convenience, tools, llm
 ;; URL: https://github.com/AnselmC/le-gpt.el
 ;; License: MIT
@@ -20,12 +20,14 @@
 ;; - Multiple chats with different models
 ;; - Completion at point
 ;; - Region transformations
-;; - Context awareness
+;; - Context awareness (files, buffers, and ad-hoc snippets)
+;; - System prompt snippets
 ;;; Code:
 
 (require 'markdown-mode)
 
 (require 'le-gpt-core)
+(require 'le-gpt-snippets)
 (require 'le-gpt-chat)
 (require 'le-gpt-transform)
 (require 'le-gpt-completion)
@@ -55,13 +57,6 @@ interactively select context files to be used for this command."
   (interactive "P")
   (le-gpt-completion-at-point use-context))
 
-;;;###autoload
-(defun le-gpt-interrupt ()
-  "Interrupt the currently running GPT process."
-  (interactive)
-  (le-gpt-interrupt))
-
-
 (defgroup le-gpt nil
   "Customization group for Le GPT."
   :group 'applications)
